==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/AppointmentCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Appointment;
import microsoft.dynamics.crm.entity.request.ActioncardRequest;
import microsoft.dynamics.crm.entity.request.ActivitymimeattachmentRequest;
import microsoft.dynamics.crm.entity.request.ActivitypartyRequest;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.AppointmentRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.ConnectionRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.PostfollowRequest;
import microsoft.dynamics.crm.entity.request.PostregardingRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.QueueitemRequest;
import microsoft.dynamics.crm.entity.request.SlakpiinstanceRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class AppointmentCollectionRequest extends CollectionPageEntityRequest<Appointment, AppointmentRequest>{

    protected ContextPath contextPath;

    public AppointmentCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Appointment.class, cp -> new AppointmentRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public PostregardingCollectionRequest appointment_PostRegardings() {
        return new PostregardingCollectionRequest(contextPath.addSegment("appointment_PostRegardings"), Optional.empty());
    }

    public PostregardingRequest appointment_PostRegardings(String postregardingid) {
        return new PostregardingRequest(contextPath.addSegment("appointment_PostRegardings").addKeys(new NameValue(postregardingid.toString())), Optional.empty());
    }

    public PostfollowCollectionRequest appointment_PostFollows() {
        return new PostfollowCollectionRequest(contextPath.addSegment("appointment_PostFollows"), Optional.empty());
    }

    public PostfollowRequest appointment_PostFollows(String postfollowid) {
        return new PostfollowRequest(contextPath.addSegment("appointment_PostFollows").addKeys(new NameValue(postfollowid.toString())), Optional.empty());
    }

    public QueueitemCollectionRequest appointment_QueueItem() {
        return new QueueitemCollectionRequest(contextPath.addSegment("Appointment_QueueItem"), Optional.empty());
    }

    public QueueitemRequest appointment_QueueItem(String queueitemid) {
        return new QueueitemRequest(contextPath.addSegment("Appointment_QueueItem").addKeys(new NameValue(queueitemid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest appointment_Annotation() {
        return new AnnotationCollectionRequest(contextPath.addSegment("Appointment_Annotation"), Optional.empty());
    }

    public AnnotationRequest appointment_Annotation(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("Appointment_Annotation").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest appointment_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("Appointment_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest appointment_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("Appointment_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest appointment_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("Appointment_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest appointment_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("Appointment_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public ActivitypartyCollectionRequest appointment_activity_parties() {
        return new ActivitypartyCollectionRequest(contextPath.addSegment("appointment_activity_parties"), Optional.empty());
    }

    public ActivitypartyRequest appointment_activity_parties(String activitypartyid) {
        return new ActivitypartyRequest(contextPath.addSegment("appointment_activity_parties").addKeys(new NameValue(activitypartyid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest appointment_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("Appointment_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest appointment_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("Appointment_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest appointment_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("Appointment_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest appointment_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("Appointment_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest appointment_connections1() {
        return new ConnectionCollectionRequest(contextPath.addSegment("appointment_connections1"), Optional.empty());
    }

    public ConnectionRequest appointment_connections1(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("appointment_connections1").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public SlakpiinstanceCollectionRequest slakpiinstance_appointment() {
        return new SlakpiinstanceCollectionRequest(contextPath.addSegment("slakpiinstance_appointment"), Optional.empty());
    }

    public SlakpiinstanceRequest slakpiinstance_appointment(String slakpiinstanceid) {
        return new SlakpiinstanceRequest(contextPath.addSegment("slakpiinstance_appointment").addKeys(new NameValue(slakpiinstanceid.toString())), Optional.empty());
    }

    public ActivitymimeattachmentCollectionRequest appointment_activity_mime_attachment() {
        return new ActivitymimeattachmentCollectionRequest(contextPath.addSegment("appointment_activity_mime_attachment"), Optional.empty());
    }

    public ActivitymimeattachmentRequest appointment_activity_mime_attachment(String activitymimeattachmentid) {
        return new ActivitymimeattachmentRequest(contextPath.addSegment("appointment_activity_mime_attachment").addKeys(new NameValue(activitymimeattachmentid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest appointment_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("Appointment_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest appointment_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("Appointment_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest appointment_principalobjectattributeaccess() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("appointment_principalobjectattributeaccess"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest appointment_principalobjectattributeaccess(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("appointment_principalobjectattributeaccess").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest appointment_connections2() {
        return new ConnectionCollectionRequest(contextPath.addSegment("appointment_connections2"), Optional.empty());
    }

    public ConnectionRequest appointment_connections2(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("appointment_connections2").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public ActioncardCollectionRequest appointment_actioncard() {
        return new ActioncardCollectionRequest(contextPath.addSegment("appointment_actioncard"), Optional.empty());
    }

    public ActioncardRequest appointment_actioncard(String actioncardid) {
        return new ActioncardRequest(contextPath.addSegment("appointment_actioncard").addKeys(new NameValue(actioncardid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest appointment_ProcessSessions() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("Appointment_ProcessSessions"), Optional.empty());
    }

    public ProcesssessionRequest appointment_ProcessSessions(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("Appointment_ProcessSessions").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/AppointmentCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Appointment;
import microsoft.dynamics.crm.entity.request.ActioncardRequest;
import microsoft.dynamics.crm.entity.request.ActivitymimeattachmentRequest;
import microsoft.dynamics.crm.entity.request.ActivitypartyRequest;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.AppointmentRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.ConnectionRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.PostfollowRequest;
import microsoft.dynamics.crm.entity.request.PostregardingRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.QueueitemRequest;
import microsoft.dynamics.crm.entity.request.SlakpiinstanceRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class AppointmentCollectionRequest extends CollectionPageEntityRequest<Appointment, AppointmentRequest>{

    protected ContextPath contextPath;

    public AppointmentCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Appointment.class, cp -> new AppointmentRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public PostregardingCollectionRequest appointment_PostRegardings() {
        return new PostregardingCollectionRequest(contextPath.addSegment("appointment_PostRegardings"), Optional.empty());
    }

    public PostregardingRequest appointment_PostRegardings(String postregardingid) {
        return new PostregardingRequest(contextPath.addSegment("appointment_PostRegardings").addKeys(new NameValue(postregardingid.toString())), Optional.empty());
    }

    public PostfollowCollectionRequest appointment_PostFollows() {
        return new PostfollowCollectionRequest(contextPath.addSegment("appointment_PostFollows"), Optional.empty());
    }

    public PostfollowRequest appointment_PostFollows(String postfollowid) {
        return new PostfollowRequest(contextPath.addSegment("appointment_PostFollows").addKeys(new NameValue(postfollowid.toString())), Optional.empty());
    }

    public QueueitemCollectionRequest appointment_QueueItem() {
        return new QueueitemCollectionRequest(contextPath.addSegment("Appointment_QueueItem"), Optional.empty());
    }

    public QueueitemRequest appointment_QueueItem(String queueitemid) {
        return new QueueitemRequest(contextPath.addSegment("Appointment_QueueItem").addKeys(new NameValue(queueitemid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest appointment_Annotation() {
        return new AnnotationCollectionRequest(contextPath.addSegment("Appointment_Annotation"), Optional.empty());
    }

    public AnnotationRequest appointment_Annotation(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("Appointment_Annotation").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest appointment_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("Appointment_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest appointment_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("Appointment_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest appointment_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("Appointment_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest appointment_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("Appointment_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public ActivitypartyCollectionRequest appointment_activity_parties() {
        return new ActivitypartyCollectionRequest(contextPath.addSegment("appointment_activity_parties"), Optional.empty());
    }

    public ActivitypartyRequest appointment_activity_parties(String activitypartyid) {
        return new ActivitypartyRequest(contextPath.addSegment("appointment_activity_parties").addKeys(new NameValue(activitypartyid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest appointment_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("Appointment_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest appointment_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("Appointment_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest appointment_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("Appointment_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest appointment_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("Appointment_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest appointment_connections1() {
        return new ConnectionCollectionRequest(contextPath.addSegment("appointment_connections1"), Optional.empty());
    }

    public ConnectionRequest appointment_connections1(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("appointment_connections1").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public SlakpiinstanceCollectionRequest slakpiinstance_appointment() {
        return new SlakpiinstanceCollectionRequest(contextPath.addSegment("slakpiinstance_appointment"), Optional.empty());
    }

    public SlakpiinstanceRequest slakpiinstance_appointment(String slakpiinstanceid) {
        return new SlakpiinstanceRequest(contextPath.addSegment("slakpiinstance_appointment").addKeys(new NameValue(slakpiinstanceid.toString())), Optional.empty());
    }

    public ActivitymimeattachmentCollectionRequest appointment_activity_mime_attachment() {
        return new ActivitymimeattachmentCollectionRequest(contextPath.addSegment("appointment_activity_mime_attachment"), Optional.empty());
    }

    public ActivitymimeattachmentRequest appointment_activity_mime_attachment(String activitymimeattachmentid) {
        return new ActivitymimeattachmentRequest(contextPath.addSegment("appointment_activity_mime_attachment").addKeys(new NameValue(activitymimeattachmentid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest appointment_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("Appointment_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest appointment_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("Appointment_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest appointment_principalobjectattributeaccess() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("appointment_principalobjectattributeaccess"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest appointment_principalobjectattributeaccess(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("appointment_principalobjectattributeaccess").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest appointment_connections2() {
        return new ConnectionCollectionRequest(contextPath.addSegment("appointment_connections2"), Optional.empty());
    }

    public ConnectionRequest appointment_connections2(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("appointment_connections2").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public ActioncardCollectionRequest appointment_actioncard() {
        return new ActioncardCollectionRequest(contextPath.addSegment("appointment_actioncard"), Optional.empty());
    }

    public ActioncardRequest appointment_actioncard(String actioncardid) {
        return new ActioncardRequest(contextPath.addSegment("appointment_actioncard").addKeys(new NameValue(actioncardid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest appointment_ProcessSessions() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("Appointment_ProcessSessions"), Optional.empty());
    }

    public ProcesssessionRequest appointment_ProcessSessions(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("Appointment_ProcessSessions").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

}
